@@ -156,6 +156,7 @@ mids <- function(
     predictorMatrix = matrix(),
     visitSequence = character(),
     formulas = list(),
+    calltype = character(),
     post = character(),
     blots = list(),
     ignore = logical(),
@@ -182,6 +183,7 @@ mids <- function(
     predictorMatrix = predictorMatrix,
     visitSequence = visitSequence,
     formulas = formulas,
+    calltype = calltype,
     post = post,
     blots = blots,
     ignore = ignore,
