@@ -9,6 +9,21 @@ test_that("long and all produce same data", {
   expect_equal(lng, all)
 })
 
+# preserve rownames type
+nhanes3 <- mice::nhanes
+row.names(nhanes3) <- seq_len(nrow(nhanes3))
+imp <- mice(nhanes, maxit = 1, m = 2, seed = 123, print = FALSE)
+imp3 <- mice(nhanes3, maxit = 1, m = 2, seed = 123, print = FALSE)
+test_that("mice() preserves the rownames type attribute", {
+  expect_type(attr(imp$data, "row.names"), "character")
+  expect_type(attr(imp3$data, "row.names"), "integer")
+})
+cmp <- complete(imp, "long")
+cmp3 <- complete(imp3, "long")
+test_that("complete() preserves the rownames type attribute", {
+  expect_type(attr(cmp, "row.names"), "character")
+  expect_type(attr(cmp3, "row.names"), "integer")
+})
 
 # mids workflow using saved objects
 imp <- mice(nhanes, seed = 123, print = FALSE)
